---
title: <span class="badge object-type-scalar"></span> WattHour
---
# <span class="badge object-type-scalar"></span> WattHour

Energy: Watt-hour (Wh)

## Definition

```python
# Energy: Watt-hour (Wh)
WattHour: typing.Literal["watth"] = "watth"
```
